@@ -83,12 +83,12 @@ struct APXREGISTRY {
     HKEY    hServKey;   /* service key */
     HKEY    hUserKey;   /* user key */
     HKEY    hCurrKey;   /* Current opened key */
-    LPVOID  pCurrVal;   /* Current value, overwritten on a next call */
+    LPVOID  pCurrVal;   /* Current value, overwitten on a next call */
     HKEY    hRparamKey; /* root\\Parameters */
     HKEY    hSparamKey; /* service\\Parameters */
     HKEY    hUparamKey; /* service\\Parameters */
     REGSAM  samOptions;
-    /** list entry for opened subkeys  */
+    /** list enty for opened subkeys  */
     TAILQ_HEAD(_lSubkeys, APXREGSUBKEY) lSubkeys;
 
 };
@@ -856,17 +856,13 @@ BOOL apxGetServiceDescriptionW(LPCWSTR szServiceName, LPWSTR szDescription,
     WCHAR wcName[SIZ_RESLEN];
     DWORD rc, l = dwDescriptionLength * sizeof(WCHAR);
     DWORD t = REG_SZ;
-    int iServiceNameLen = lstrlenW(szServiceName);
-    if (iServiceNameLen > SIZ_RESMAX) {
-        apxLogWrite(APXLOG_MARK_WARN "Can't read service description because registry key '%s' length %d > %d", szServiceName, iServiceNameLen, SIZ_RESMAX);
+    if (lstrlenW(szServiceName) > SIZ_RESMAX)
         return FALSE;
-    }
     lstrcpyW(wcName, REGSERVICE_ROOT);
     lstrcatW(wcName, szServiceName);
 
     rc = RegOpenKeyExW(HKEY_LOCAL_MACHINE, wcName, 0, KEY_READ, &hKey);
     if (rc != ERROR_SUCCESS) {
-        apxLogWrite(APXLOG_MARK_WARN "Can't read service description because registry key '%s' cannot be opened (rc = %d)", wcName, rc);
         return FALSE;
     }
     rc = RegQueryValueExW(hKey, REGDESCRIPTION, NULL, &t, (BYTE *)szDescription,
@@ -874,10 +870,8 @@ BOOL apxGetServiceDescriptionW(LPCWSTR szServiceName, LPWSTR szDescription,
     SAFE_CLOSE_KEY(hKey);
     if (rc == ERROR_SUCCESS && t == REG_SZ)
         return TRUE;
-    else {
-        apxLogWrite(APXLOG_MARK_WARN "Can't read service description because registry key '%s' cannot query value at '%s' (rc = %d)", wcName, REGDESCRIPTION, rc);
+    else
         return FALSE;
-    }
 }
 
 BOOL apxGetServiceUserW(LPCWSTR szServiceName, LPWSTR szUser,
